@@ -5,22 +5,34 @@ plot.forestFloor_regression = function(x,
                                        orderByImportance=TRUE, 
                                        cropXaxes=NULL, 
                                        crop_limit=4,
-                                       plot_GOF=FALSE,
-                                       GOF_col = "#33333399",
+                                       plot_GOF=TRUE,
+                                       GOF_args = list(col="#33333399"),
                                        speedup_GOF = TRUE,
                                        ...){
+  #pre-checking graphial parameters, and split into separate lists
+  moreArgs = list(...) #args passed to par() if no match, passed instead to plot(,...) 
+  pars = par(no.readonly = TRUE) #save previous graphical parameters
+  toPlotOnly=c("cex","col") #these args always passed to plot(,...)
+  #TRUE/FALSE vector, passed to par() (TRUE) or plot() FALSE
+  parArgs.ind = mapply("&&", 
+                        names(moreArgs) %in% names(pars),#is a par-arg  match
+                       !names(moreArgs) %in% toPlotOnly  #not par-excluded
+  )
+  if(length(parArgs.ind)==0) {
+    userArgs.plot=list()
+    userArgs.par =list()
+  } else {
+    userArgs.plot = moreArgs[!parArgs.ind]
+    userArgs.par  = moreArgs[ parArgs.ind]
+  }
   
-  pars = par(no.readonly = TRUE) #save previous graphical par(emeters)
-  par(mar=c(2.2,2.2,1.2,1.2),cex=.5) #changing par, narrowing plot margins, smaller points
-  
-  #short for phys.val and feature contribution in object
-  
+  #short for features and feature contribution in object
   X = x$X
   FCs = x$FCmatrix
   if(plot_GOF && is.null(x$FCfit)) { 
     #compute goodness of fit of one way presentation
     #leave-one-out k-nearest neighbor(guassian kernel), kknn package
-    print("compute goodness-of-fit with leave-one-out k-nearest neighbor(guassian kernel), kknn package")
+    print("compute goodness-of-fit with leave-one-out k-nearest neighbor(guassian weighting), kknn package")
     if(speedup_GOF) { #reduce observatioins to compute forest GOF
       obs = length(x$Y)
       reduce.exp = 1 - 0.025  * sum(obs>c(500,700,1000,1500,2500,4500,10000,20000))
@@ -63,11 +75,24 @@ plot.forestFloor_regression = function(x,
     if(is.character(X[,i])) X[,i] = as.numeric(X[,i])
   } 
   
-  ##get dimensions of plots
+  ##get dimensions of plots and set graphical (par)ameters
   n.plots = min(dim(X)[2],length(plot_seq))
   plotdims.y = min(ceiling(n.plots/3),5)
   plotdims.x = min(3 , n.plots)
-  par(mfrow=c(plotdims.y,plotdims.x))
+  if(n.plots==4) {
+    plotdims.x=2
+    plotdims.y=2
+  }
+  
+  stdArgs.par = list(
+    mar=c(2.2,2.2,1.2,1.2),
+    cex=.5,
+    mfrow=c(plotdims.y,plotdims.x))
+  
+  args.par = append.overwrite.alists(
+    userArgs.par, #userArgs for par() [MASTER args]
+     stdArgs.par) #std args for par() [SLAVE args]
+  par(args.par) #changing par, narrowing plot margins, smaller points
   
   ##get importance for plotting
   imp = x$importance     #fetch importance
@@ -85,12 +110,16 @@ plot.forestFloor_regression = function(x,
       limitX = FALSE
     }
     
-    plot(
-      data.frame( # data to plot
-        physical.value        = jitter(X[,imp.ind[i]],
-                                       factor=jitter.template[imp.ind[i]]*2),
-        partial.contribution  = FCs[,imp.ind[i]]
+    #arguments for plooting
+    
+    stdArgs.plot = alist(
+      
+      #the XY coordinates to plot
+      x = data.frame(
+      physical.value = jitter(X[,imp.ind[i]],factor=jitter.template[imp.ind[i]]*2),
+      partial.contribution  = FCs[,imp.ind[i]]
       ),
+      #the title
       main = if(!plot_GOF) names(imp)[imp.ind[i]] else {
         imp=imp
         imp.ind = imp.ind
@@ -99,15 +128,25 @@ plot.forestFloor_regression = function(x,
         theNumber = round(GOFs[imp.ind[i]],2)
         paste0(theName,",R^2= ",theNumber)
       },
-      ylim = list(NULL,range(FCs))[[limitY+1]], #same Yaxis if limitY == TRUE
-      xlim = list(NULL,range(Xsd))[[limitX+1]],
-      ...
+      
+      #plot limits
+      ylim = list(NULL,range(FCs))[[limitY+1]],
+      xlim = list(NULL,range(Xsd))[[limitX+1]]
     )
+    
+    #merge args.plot with user args(...), conflicts resolved by ...
+    allArgs.plot = append.overwrite.alists(userArgs.plot,stdArgs.plot)
+    do.call(plot,allArgs.plot)
+      
     if(plot_GOF) {
       X_unique = sort(unique(x$X[,imp.ind[i]])) #refer to x, as may be reduced by speedup_GOF
       X_unique.ind = match(X_unique,x$X[,imp.ind[i]]) #refer to x not X
       FC_match = x$FCfit[X_unique.ind,imp.ind[i]]     #refer to x not X
-      points(X_unique,FC_match,col=GOF_col,type="l",lwd=2)
+      allArgs.points = append.overwrite.alists(
+        GOF_args,
+        alist(x=X_unique,y=FC_match,type="l",lwd=2)
+      )
+      do.call(points,allArgs.points)
     }
   }
   pars = with(pars,if(exists("pin")) {
